import os

import polars as pl
import json
json_path = 'samantha20.json'

adding_df = pl.DataFrame(
    data={'name':['donut'],
          'height':[13.4]}
)
print(adding_df)

if os.path.exists(json_path):
    df = pl.read_json(json_path)
else:
    raise RuntimeError('sorry, the specified path does not exist')
print(df)

concated_df = pl.concat([df, adding_df], how='vertical_relaxed')
print(concated_df)

concated_df.write_json('bingo.json')



from setuptools import setup, find_packages

VERSION = '0.0.5'
DESCRIPTION = 'Partner Simulator'
with open('partnersimulator/ReadMe.md', 'r') as f:
    LONG_DESCRIPTION = f.read()

setup(
    name='partnersimulator',
    version=VERSION,
    author='Aditya Jain',
    author_email='aditya.jain22@imperial.ac.uk',
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type='text/markdown',
    packages=find_packages(),
    install_requires=['openai', 'polars'],
    keywords=['creepy','parasocial'],
    classifiers=[
            "Development Status :: 3 - Alpha",
            "Intended Audience :: Education",
            "Programming Language :: Python :: 2",
            "Programming Language :: Python :: 3",
            "Operating System :: MacOS :: MacOS X",
            "Operating System :: Microsoft :: Windows"
    ]
)


from openai import OpenAI
import polars as pl
import os
API_KEY =input('What is your OpenAI API key?: ')
client = OpenAI(api_key=API_KEY) #leaving this as is for now but please don't abuse my kindness

class partner:
    def __init__(self, name, age, gender, mood, affection):
        self.name = name
        self.age = age
        self.gender = gender
        self.mood = mood
        self.affection = affection
        self.json_path = f'{self.name}{self.age}.json'

        if self.age < 18:
            raise RuntimeError(f'An age of {self.age} is too young!')

    def __str__(self):
        return f'{self.name}, {self.age}, {self.gender} {self.mood}, {self.affection}'

    def read_chat_history(self):
        if not os.path.exists(self.json_path):
            df = pl.DataFrame({
                'role': ['user'],
                'content': ['']
            })
            df.write_json(self.json_path)
        existing_df = pl.read_json(self.json_path)
        return existing_df

    def write_chat_history(self, prompt, message):
        history_df = self.read_chat_history()
        addendum_df = pl.DataFrame({
            'role' : ['user', 'system'],
            'content': [prompt, message]
        })
        combined_df = pl.concat([history_df, addendum_df], how='vertical_relaxed')
        combined_df.write_json(self.json_path)

    def send_message(self, prompt):
        response = client.responses.create(
            model='gpt-4.1',
            input=[
                {
                    'role': 'system',
                    'content': f'''Take on the role of a romantic partner. Your attributes are as follows:
                                name: {self.name},
                                age: {self.age} year(s) old,
                                gender: {self.gender},
                                mood {self.mood},
                                affection: {self.affection}/100.
                                Respond to the prompt according to these attributes. Make sure the style, tone, and language are in line with the attributes i gave you. Tailor the response to each attribute'''
                },
                {
                    'role': 'system',
                    'content': f'{self.read_chat_history()}'
                },
                {
                    'role': 'user',
                    'content': f'{prompt}'
                }
            ]
        )
        self.write_chat_history(prompt, response.output_text)
        return response.output_text